==> haskell-dec-0.0.5-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dec
version:              0.0.5
visibility:           public
id:                   dec-0.0.5-3XcHsBR9yr55pCvIxgalEN
key:                  dec-0.0.5-3XcHsBR9yr55pCvIxgalEN
license:              BSD-3-Clause
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Neg a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Neg a)
    @

category:             Data, Dependent Types
abi:                  5b0ea8ec1ceab0af5af85f60c6feb848
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dec
hs-libraries:         HSdec-0.0.5-3XcHsBR9yr55pCvIxgalEN
depends:              base-4.17.2.1 boring-0.2.1-J4SnML7YpXV9bowsupJp7A
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dec-0.0.5-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dec
version:              0.0.5
visibility:           public
id:                   dec-0.0.5-LudXni7GAoCESRm5TpcXOv
key:                  dec-0.0.5-LudXni7GAoCESRm5TpcXOv
license:              BSD-3-Clause
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Neg a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Neg a)
    @

category:             Data, Dependent Types
abi:                  562c47cdf26ca5ef40a12259b1d38b39
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dec
hs-libraries:         HSdec-0.0.5-LudXni7GAoCESRm5TpcXOv
depends:              base-4.17.2.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
